/**
 * @author SrinivasJasti
 * 
 */

package org.srinivas.siteworks.controllers;

import static org.junit.Assert.fail;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.web.servlet.MockMvc;
import org.springframework.test.web.servlet.request.MockMvcRequestBuilders;
import org.springframework.test.web.servlet.setup.MockMvcBuilders;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;


@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration
public class JasperReportsControllerTest {
	
	private static final Logger logger = LoggerFactory.getLogger(JasperReportsControllerTest.class);


	@Autowired
	private JasperReportsController jasperReportsController;

	/**
	 * Test jasper reports page.
	 */
	@Test
	public void testJasperReportsPage() {
		MockMvc mockMvc = MockMvcBuilders.standaloneSetup(this.jasperReportsController).build();
		try {
			mockMvc.perform(MockMvcRequestBuilders.get("/jasperreport.html")).andExpect(status().isOk()).andExpect(view().name("jasperreport")).andExpect(forwardedUrl("jasperreport")).andExpect(handler().methodName("reportPage")).andExpect(model().attribute("message", JasperReportsController.STRING_MESSAGE_WELCOME_TO_WEB_APPLICATION_INITIALISER_INTEGRATED_WITH_JASPER_REPORTS));

		} catch (Exception e) {
			logger.info(e.getMessage());
			fail("Failed Due to: " + e.getMessage());
		}

	}

	/**
	 * Test jasper reports pdf page.
	 */
	@Test
	public void testJasperReportsPdfPage() {

		MockMvc mockMvc = MockMvcBuilders.standaloneSetup(this.jasperReportsController).build();
		try {
			mockMvc.perform(MockMvcRequestBuilders.get("/jasperreport/pdf.html")).andExpect(status().isOk()).andExpect(view().name("pdfReport")).andExpect(forwardedUrl("pdfReport")).andExpect(handler().methodName("generatePdfReport"));

		} catch (Exception e) {
			logger.info(e.getMessage());
			fail("Failed Due to: " + e.getMessage());
		}

	}

	/**
	 * Test jasper reports xls page.
	 */
	@Test
	public void testJasperReportsXLSPage() {

		MockMvc mockMvc = MockMvcBuilders.standaloneSetup(this.jasperReportsController).build();
		try {
			mockMvc.perform(MockMvcRequestBuilders.get("/jasperreport/xls.html")).andExpect(status().isOk()).andExpect(view().name("xlsReport")).andExpect(forwardedUrl("xlsReport")).andExpect(handler().methodName("generateXlsReport"));
		} catch (Exception e) {
			logger.info(e.getMessage());
			fail("Failed Due to: " + e.getMessage());
		}

	}


	@Configuration
	static class JasperReportsControllerTestConfiguration {

		/**
		 * Jasper reports controller. 
		 * @return the jasper reports controller
		 */
		@Bean
		public JasperReportsController jasperReportsController() {
			return new JasperReportsController();
		}
	}

}
